# Generated by Django 2.2.5 on 2020-02-02 14:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('news', '0008_category_title'),
    ]

    operations = [
        migrations.AddField(
            model_name='filterpost',
            name='icon_inactive',
            field=models.FileField(blank=True, null=True, upload_to='filters/', verbose_name='Изображение не активной иконки'),
        ),
    ]
