# Generated by Django 3.0.3 on 2020-02-29 09:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('news', '0009_filterpost_icon_inactive'),
    ]

    operations = [
        migrations.AlterField(
            model_name='post',
            name='category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='category_posts', to='news.Category', verbose_name='Категория'),
        ),
    ]
