# Generated by Django 3.0.3 on 2020-03-03 16:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pages', '0005_auto_20191211_1756'),
    ]

    operations = [
        migrations.AddField(
            model_name='blockpage',
            name='background_color',
            field=models.CharField(blank=True, max_length=7, null=True, verbose_name='Цвет фона'),
        ),
    ]
